@@ -1,3 +1,4 @@
+import json
 from couchdbkit import BadValueError
 from couchdbkit.ext.django.schema import (Document, StringProperty, IntegerProperty, StringListProperty, Property,
                                           DocumentSchema, SchemaListProperty, ListProperty, BooleanProperty)
@@ -6,6 +7,13 @@ from datetime import datetime, date
 import sqlalchemy
 import re
 
+EQUAL = '=='
+NOT_EQUAL = '!='
+MATCH_OPS = [EQUAL, NOT_EQUAL]
+MATCH_OPS_FUNC = {
+    EQUAL: lambda input, reference: input == reference,
+    NOT_EQUAL: lambda input, reference: input != reference,
+}
 
 def validate_name(value, search=re.compile(r'[^a-zA-Z0-9_]').search):
     if not value or bool(search(value)):
@@ -20,9 +28,22 @@ class RowMatcher(object):
 class KeyMatcher(DocumentSchema, RowMatcher):
     index = IntegerProperty()
     value = StringProperty()
+    operator = StringProperty(choices=MATCH_OPS, default=EQUAL)
 
     def matches(self, row_key, row_value):
-        return row_key[self.index] == self.value if len(row_key) > self.index else False
+        try:
+            op = MATCH_OPS_FUNC.get(self.operator)
+            key_value = row_key[self.index]
+            reference = self.value
+            if not isinstance(key_value, basestring):
+                try:
+                    reference = json.loads(self.value)
+                except ValueError:
+                    pass
+
+            return op(key_value, reference)
+        except IndexError:
+            return False
 
 
 class ColumnDef(DocumentSchema):
@@ -56,12 +77,17 @@ class ColumnDef(DocumentSchema):
         use_index = self.value_index is not None
         use_attr = self.value_attribute is not None
 
-        if self.value_source == "key" and use_index:
-            return key[self.value_index]
-        elif self.value_source == "value" and (use_index or use_attr):
-            return value[self.value_index if use_index else self.value_attribute]
-        else:
-            return value
+        try:
+            if self.value_source == "key" and use_index:
+                return key[self.value_index]
+            elif self.value_source == "value" and (use_index or use_attr):
+                return value[self.value_index if use_index else self.value_attribute]
+            else:
+                return value
+        except IndexError:
+            raise IndexError('Value index out of range: %s[%s]' % (self.value_source, self.value_index))
+        except KeyError:
+            raise KeyError('Value attribute error: %s[%s]' % (self.value_source, self.value_attribute))
 
     def convert_type(self, value):
         if value is None:
@@ -147,6 +173,8 @@ class SqlExtractMapping(Document):
 
     couch_view = StringProperty(required=True)
     couch_key_prefix = ListProperty(default=[])
+    couch_group_level = IntegerProperty()
+    """Group level parameter for CouchDB query. Leave blank for 'exact' grouping."""
     couch_date_range = IntegerProperty(default=-1)
     """Number of days in the past to query data for. This assumes that the first
     element in the view key (after the key prefix) is a date."""
@@ -161,6 +189,12 @@ class SqlExtractMapping(Document):
     def key_columns(self):
         return [c.name for c in self.columns if c.is_key_column]
 
+    def validate(self, required=True):
+        super(SqlExtractMapping, self).validate(required)
+
+        if self.couch_group_level is not None and self.couch_group_level < 0:
+                raise BadValueError('Couch Group Level must be >= 0')
+
     @classmethod
     def all(cls):
         return cls.view('ctable/by_name',
